#!/bin/bash

function check_exported_variable ()
{
	outline=$(printenv | grep $1)
	if [[ "" == "$outline" ]] || [[ ! "$outline" =~ "vlibras" ]]; then
    	eval 'export '$1'='$2
    fi
}

function is_digit()
{
    digit_regex='^[0-9]+$'
    if [[ $1 =~ $digit_regex ]] ; then
        echo "1"
    else
        echo "0"
    fi
}

check_exported_variable "HUNPOS_TAGGER" "/opt/vlibras_aelius/bin/hunpos-tag"
check_exported_variable "AELIUS_DATA" "/opt/vlibras_aelius/aelius_data"
check_exported_variable "NLTK_DATA" "/opt/vlibras_aelius/nltk_data"
check_exported_variable "TRANSLATE_DATA" "/opt/vlibras_desktop/translate/data/"
check_exported_variable "PYTHONPATH" "/opt/vlibras_desktop/translate:/opt/vlibras_aelius:/opt/vlibras_desktop/bin/orca-sc:${PYTHONPATH}"

# check if the vlibras-aelius package is installed and if not, call the
# script depends_install.sh to install it.
PKG_AELIUS=$(dpkg-query -W --showformat='${Status}\n' vlibras-aelius | grep "install ok installed")
if [ "" == "$PKG_AELIUS" ]; then
	gksudo -m "<b>Uma atualização necessária foi encontrada! Digite sua senha para instalar.</b>" "gnome-terminal --hide-menubar -x bash -c '/./opt/vlibras_desktop/script/depends_install.sh vlibras-aelius;'"
fi

# delimiter
IFS="."

# get vlibras-desktop version from repository
player_version_remote=$(curl -s 'http://atualizacao.vlibras.lavid.ufpb.br/version/player')
# put tokenized remote dicionario-vlibras version in the array
arrv_remote_p=($player_version_remote)

# consider "3.2.1" like "<release>.<maintanance>.<build>"  

PKG_PLAYER=$(dpkg-query -W --showformat='${Status}\n' vlibras-desktop | grep "install ok installed")

# if true, exists a version installed and check for update
if [ "$PKG_PLAYER" != "" ]; then

	UPDATE="0"

	# get local vlibras-desktop version
	player_version_local=$(dpkg-query -W --showformat='${Version}\n' vlibras-desktop)
	# put tokenized local vlibras-desktop version in the array
	arrv_local_p=($player_version_local)

	# compare major release number
	if [ "$((${arrv_remote_p[0]}))" -gt "$((${arrv_local_p[0]}))" ]; then
	    UPDATE="1"
	elif [[ "$((${arrv_remote_p[0]}))" -eq "$((${arrv_local_p[0]}))" ]]; then
		# compare maintenance release number
	    if [ "$((${arrv_remote_p[1]}))" -gt "$((${arrv_local_p[1]}))" ]; then
	        UPDATE="1"    
	    elif [[ "$((${arrv_remote_p[1]}))" -eq "$((${arrv_local_p[1]}))" ]]; then
	    	# compare build number
	        if [ "$((${arrv_remote_p[2]}))" -gt "$((${arrv_local_p[2]}))" ]; then
	            UPDATE="1"
	        fi
	    fi
	fi

	# if exist a new version to install, UPDATE variable is "1"
	if [ "$UPDATE" == "1" ]; then
		gksudo -m "<b>Uma atualização necessária foi encontrada! Digite sua senha para instalar.</b>" "gnome-terminal --hide-menubar -x bash -c '/./opt/vlibras_desktop/script/update_vlibras.sh vlibras-desktop;'"
	fi

fi


### CHECK FOR UPDATES OF THE dicionario-vlibras


# get dicionario-vlibras version from repository
dict_version_remote=$(curl -s 'http://atualizacao.vlibras.lavid.ufpb.br/version/dict')
# put tokenized remote dicionario-vlibras version in the array
arrv_remote_d=($dict_version_remote)

PKG_DICT=$(dpkg-query -W --showformat='${Status}\n' dicionario-vlibras | grep "install ok installed")

# if true, exists a version installed and check for update
if [ "$PKG_DICT" != "" ]; then

	UPDATE="0"

	# get local dicionario-vlibras version
	dict_version_local=$(dpkg-query -W --showformat='${Version}\n' dicionario-vlibras)
	# put tokenized local vlibras-desktop version in the array
	arrv_local_d=($dict_version_local)

	# compare major release number
	if [ "$((${arrv_remote_d[0]}))" -gt "$((${arrv_local_d[0]}))" ]; then
	    UPDATE="1"
	elif [[ "$((${arrv_remote_d[0]}))" -eq "$((${arrv_local_d[0]}))" ]]; then
		# compare maintenance release number
	    if [ "$((${arrv_remote_d[1]}))" -gt "$((${arrv_local_d[1]}))" ]; then
	        UPDATE="1"    
	    elif [[ "$((${arrv_remote_d[1]}))" -eq "$((${arrv_local_d[1]}))" ]]; then
	    	# compare build number
	        if [ "$((${arrv_remote_d[2]}))" -gt "$((${arrv_local_d[2]}))" ]; then
	            UPDATE="1"
	        fi
	    fi
	fi

# otherwise, not exists any version of dicionario-vlibras installed, therefore,
# try install the version available from repository
else
	gksudo -m "<b>Uma instalação necessária foi encontrada! Digite sua senha para instalar.</b>" "gnome-terminal --hide-menubar -x bash -c '/./opt/vlibras_desktop/script/depends_install.sh dicionario-vlibras;'"
fi



# if exist a new version to install, UPDATE variable is "1"
if [ "$UPDATE" == "1" ]; then
	gksudo -m "<b>Uma atualização necessária foi encontrada! Digite sua senha para instalar.</b>" "gnome-terminal --hide-menubar -x bash -c '/./opt/vlibras_desktop/script/update_vlibras.sh dicionario-vlibras;'"
else
	if [ -f /opt/vlibras_desktop/config/dict.reset ] ; then
		gksudo -m "<b>É necessário efetuarmos um ajuste no VLibras. Por favor, digite sua senha para continuar.</b>" "gnome-terminal --hide-menubar -x bash -c 'rm /opt/vlibras_desktop/config/dict.reset;'"
	fi
fi

# Start vlibras-player
cd /opt/vlibras_desktop
./vlibras_player -single-instance > /dev/null 2>&1
