#!/bin/bash
#
#
#-------------------- IMPORTANT ------------------------
# -> To run this script you need to be a sudo user     |
#-------------------------------------------------------

set -e

notify-send -u critical -i "/opt/vlibras_desktop/vlibras_player_Data/Resources/UnityPlayer.png" VLibras "Aguarde! As atualizações do VLibras estão sendo instaladas...
Isso pode levar alguns minutos!"

# reset_dict removes the dicionario-vlibras and your patches if this version
# contains some error. The file dict.reset is used to remove it.
function reset_dict()
{
    # path to dict.reset
    DICT_RESET_FILE="/opt/vlibras_desktop/config/dict.reset"
    
    if [ -f $DICT_RESET_FILE ] ; then
        
        if [ -d "/opt/vlibras_desktop/vlibras_player_Data/Bundles" ]; then

            COUNT_FILES="$(ls /opt/vlibras_desktop/vlibras_player_Data/Bundles/*.description | wc -l)"
            
            if [ "$(($COUNT_FILES))" -gt "0" ]; then
                
                apt-get remove --purge --force-yes --yes dicionario-vlibras > /dev/null 2>&1
                
                for i in $(seq 1 $COUNT_FILES); do
                    # remove each patch by the number version
                    apt-get remove --purge --force-yes --yes patch${i}.0.0 > /dev/null 2>&1
                done
                
                # update list packages remove all dependencies
                apt-get autoremove --force-yes --yes > /dev/null 2>&1
                apt-get autoclean --force-yes --yes > /dev/null 2>&1

                apt-get install --force-yes --yes dicionario-vlibras:i386 > /dev/null 2>&1
                
            fi
        fi

        rm $DICT_RESET_FILE  

    fi

}

function update_patches()
{
    COUNT_FILES="$(ls /opt/vlibras_desktop/vlibras_player_Data/Bundles/*.description | wc -l)"
    for i in $(seq 1 $COUNT_FILES); do
        # update each patch by the number version
        apt-get --only-upgrade --force-yes --yes patch${i}.0.0 > /dev/null 2>&1
    done
}

case $2 in
  '')
    eval "$(debconf-apt-progress --config)"
    "$0" $1 debconf 
    ;;
  debconf)
    . /usr/share/debconf/confmodule
    case $1 in
        "vlibras-aelius")
            debconf-apt-progress --start
            debconf-apt-progress --from 0 --to 30 -- apt-get update
            debconf-apt-progress --from 30 --to 100 -- apt-get install --only-upgrade --force-yes --yes vlibras-aelius
            debconf-apt-progress --stop
            ;;
        "dicionario-vlibras")
            debconf-apt-progress --start
            debconf-apt-progress --from 0 --to 30 -- apt-get update
            reset_dict
            update_patches
            debconf-apt-progress --from 30 --to 100 -- apt-get install --only-upgrade --force-yes --yes dicionario-vlibras:i386
            debconf-apt-progress --stop
            ;;
        "vlibras-desktop")
            debconf-apt-progress --start
            debconf-apt-progress --from 0 --to 30 -- apt-get update
            debconf-apt-progress --from 30 --to 100 -- apt-get install --only-upgrade --force-yes --yes vlibras-desktop
            debconf-apt-progress --stop
            ;;
        *) echo invalid option;;
    esac
esac